@@ -5,7 +5,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 use v5.36;
 
-our $VERSION = '0.0402';
+our $VERSION = '0.0403';
 
 use Moo;
 use strictures 2;
@@ -129,6 +129,17 @@ sub _filter_and_forward ($self, $dt, $event) {
 }
 
 
+sub add_filter ($self, $name, $event_type, $action) {
+    if ( ref $event_type eq 'ARRAY' ) {
+        $self->add_filter( $name, $_, $action ) for @$event_type;
+        return;
+    }
+    _log("Add $name filter for $event_type")
+        if $self->verbose;
+    push @{ $self->filters->{$event_type} }, $action;
+}
+
+
 sub send_it ($self, $event) {
     _log("Event: @$event") if $self->verbose;
     $self->_midi_out->send_event(@$event);
@@ -149,17 +160,6 @@ sub run ($self) {
     $self->loop->run;
 }
 
-
-sub add_filter ($self, $name, $event_type, $action) {
-    if ( ref $event_type eq 'ARRAY' ) {
-        $self->add_filter( $name, $_, $action ) for @$event_type;
-        return;
-    }
-    _log("Add $name filter for $event_type")
-        if $self->verbose;
-    push @{ $self->filters->{$event_type} }, $action;
-}
-
 1;
 
 __END__
@@ -174,7 +174,7 @@ MIDI::RtController - Control your MIDI controller
 
 =head1 VERSION
 
-version 0.0402
+version 0.0403
 
 =head1 SYNOPSIS
 
@@ -197,13 +197,13 @@ version 0.0402
     return 0;
   }
 
-  # capture specific events:
+  # respond to specific events:
   $rtc->add_filter('filter_tone', $_, \&filter_tone)
     for qw(note_on note_off);
   # Or:
   $rtc->add_filter('filter_tone', [qw(note_on note_off)], \&filter_tone);
 
-  # capture all events:
+  # respond to all events:
   $rtc->add_filter(
     'echo',
     all => sub {
@@ -265,6 +265,18 @@ Create a new C<MIDI::RtController> object.
 
 =for Pod::Coverage BUILD
 
+=head2 add_filter
+
+  $rtc->add_filter($name, $event_type, $action);
+
+Add a named filter, defined by the CODE reference B<action> for an
+B<event_type> like C<note_on> or C<note_off>. An ARRAY reference
+of event types like: C<[qw(note_on note_off)]> may also be given.
+
+The special event type C<all> may also be used to refer to any
+controller event (e.g. C<note_on>, C<control_change>,
+C<pitch_wheel_change>, etc.).
+
 =head2 send_it
 
   $rtc->send_it($event);
@@ -284,18 +296,6 @@ seconds) expires.
 
 Run the asynchronous B<loop>!
 
-=head2 add_filter
-
-  $rtc->add_filter($name, $event_type, $action);
-
-Add a named filter, defined by the CODE reference B<action> for an
-B<event_type> like C<note_on> or C<note_off>. An ARRAY reference
-of event types like: C<[qw(note_on note_off)]> may also be given.
-
-The special event type C<all> may also be used to refer to any
-controller event (e.g. C<note_on>, C<control_change>,
-C<pitch_wheel_change>, C<CC#>s, etc.).
-
 =head1 THANK YOU
 
 This code would not exist without the help of CPAN's JBARRETT (John
